==> speechanalytic-billing_0.1.4_database.tar.gz: database/mssql/procedures/ReportByVCCBalanceDetail.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[ReportByVCCBalanceDetail] (
	@PlatformHash VARCHAR(100)=NULL,
	@StartDate DATETIME = NULL,
	@EndDate DATETIME = NULL,
	@InstallationId VARCHAR(100)=NULL,
	@AccountId VARCHAR(50) = NULL,
	@SubAccountId VARCHAR(50) = NULL,
	@VCC VARCHAR(50) = NULL,
	@UserApi VARCHAR(50) = NULL,
	@BatchTypeName VARCHAR(50) = NULL,
	@BatchTypeId VARCHAR(50) = NULL	
	)
AS
BEGIN
	-- ESTE PROCEDURE TIENE POR FINALIDAD HACER UN REPORTE DETALLADO DE TRANSACCIONES
	SET NOCOUNT ON

	-- EN CASO EL VCC SEA SYSTEM LO IGUALAMOS A NULL
	IF @VCC = 'system' SET @VCC = NULL

	SELECT
		D.[ClientId]													'COLUMN_CLIENT_NAME',
		S.[StartDate]													'COLUMN_START_DATE',
		S.[EndDate]														'COLUMN_END_DATE',
		D.[BatchTypeName]												'COLUMN_BATCH_TYPE_NAME',
		D.[BatchTypeId]													'COLUMN_BATCH_TYPE_ID',
		D.[AccountId]													'COLUMN_ACCOUNT',
		D.[SubAccountId]												'COLUMN_SUBACCOUNT',
		D.[ApiId]														'COLUMN_API_ID',
		D.[SystemService]												'COLUMN_SYSTEM_SERVICE',
		CASE WHEN D.[SystemService] = 'TRANSCRIPTION' 
			THEN SUM(ISNULL(D.[Rate], 0)) ELSE NULL END					'COLUMN_TRANSCRIPTION_TOTAL_RATE',
		D.[RatePerSecond]												'COLUMN_TRANSCRIPTION_RATE_PER_SECOND',
		SUM(ISNULL(D.[ValidDurationTime], 0))							'COLUMN_TRANSCRIPTION_VALID_DURATION_TIME',
		S.[SemanticAnalysisRatePerTransaction]							'COLUMN_SEMANTIC_ANALYSIS_RATE_PER_TRANSACTION',
		CASE WHEN S.[TotalQueries] > 0 THEN 1 ELSE NULL END				'COLUMN_SEMANTIC_ANALYSIS_TOTAL_REQUEST',
		CASE WHEN D.[SystemService] = 'SEMANTIC_ANALYSIS' 
			THEN SUM(ISNULL(D.[Rate], 0)) ELSE NULL END					'COLUMN_SEMANTIC_ANALYSIS_TOTAL_RATE',
		S.[CognitiveAnalysisRatePerTransaction]							'COLUMN_COGNITIVE_ANALYSIS_RATE_PER_TRANSACTION',
		CASE WHEN D.[SystemService] = 'COGNITIVE_ANALYSIS' 
			THEN SUM(D.[TotalValidRequest]) ELSE NULL END				'COLUMN_COGNITIVE_ANALYSIS_TOTAL_REQUEST',
		CASE WHEN D.[SystemService] = 'COGNITIVE_ANALYSIS' 
			THEN SUM(ISNULL(D.[Rate], 0)) ELSE NULL END					'COLUMN_COGNITIVE_ANALYSIS_TOTAL_RATE',
		D.[EntityId]													'COLUMN_ENTITY_ID'
	FROM AccountSubAccountVCCDetailedTransaction D (NOLOCK)
	LEFT JOIN AccountSubAccountVCCSummaryTransaction S (NOLOCK)
		ON S.BatchID = D.BatchId
			AND S.[SystemService] = D.[SystemService]
	WHERE D.[InstallationId] IS NOT NULL
		AND   (@InstallationId IS NULL OR D.[InstallationId] = @InstallationId)
		AND   (@StartDate IS NULL OR S.[EndDate] >= @StartDate)
		AND   (@EndDate IS NULL OR S.[EndDate] <= @EndDate)
		AND   (@BatchTypeName IS NULL OR D.[BatchTypeName] = @BatchTypeName)
		AND   (@BatchTypeId IS NULL OR D.[BatchTypeId] = @BatchTypeId)
		AND   (@AccountId IS NULL OR D.[AccountId] = @AccountId)
		AND   (
				((@SubAccountId IS NULL OR @SubAccountId = 'NONE') AND D.[SubAccountId] IS NULL)
				OR (@SubAccountId = 'ALL_SUBACCOUNTS' AND D.[SubAccountId] IS NOT NULL)
				OR D.[SubAccountId] = @SubAccountId
		)
		AND   (
				(@VCC IS NOT NULL AND D.[VCC] = @VCC)
				OR D.[VCC] IS NOT NULL
			)
		AND   (@UserApi IS NULL OR S.[UserApi] = @UserApi)
	GROUP BY D.[ClientId], S.[StartDate], S.[EndDate], D.[BatchTypeName], D.[BatchTypeId], 
		D.[AccountId], D.[SubAccountId], D.[ApiId], D.[SystemService], D.[RatePerSecond], 
		S.[SemanticAnalysisRatePerTransaction], S.[TotalQueries], S.[CognitiveAnalysisRatePerTransaction], S.[TotalModelRequest], D.[EntityId]

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speechanalytic-billing_1.0.1_database.tar.gz: database/mssql/procedures/ReportByVCCBalanceDetail.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[ReportByVCCBalanceDetail] (
	@PlatformHash VARCHAR(100)=NULL,
	@StartDate DATETIME = NULL,
	@EndDate DATETIME = NULL,
	@InstallationId VARCHAR(100)=NULL,
	@AccountId VARCHAR(50) = NULL,
	@SubAccountId VARCHAR(50) = NULL,
	@VCC VARCHAR(50) = NULL,
	@UserApi VARCHAR(50) = NULL,
	@BatchTypeName VARCHAR(50) = NULL,
	@BatchTypeId VARCHAR(50) = NULL	
	)
AS
BEGIN
	-- ESTE PROCEDURE TIENE POR FINALIDAD HACER UN REPORTE DETALLADO DE TRANSACCIONES
	SET NOCOUNT ON

	-- EN CASO EL VCC SEA SYSTEM LO IGUALAMOS A NULL
	IF @VCC = 'system' SET @VCC = NULL

	SELECT
		D.[ClientId]													'COLUMN_CLIENT_NAME',
		S.[StartDate]													'COLUMN_START_DATE',
		S.[EndDate]														'COLUMN_END_DATE',
		D.[BatchTypeName]												'COLUMN_BATCH_TYPE_NAME',
		D.[BatchTypeId]													'COLUMN_BATCH_TYPE_ID',
		D.[AccountId]													'COLUMN_ACCOUNT',
		D.[SubAccountId]												'COLUMN_SUBACCOUNT',
		C.[Code]														'COLUMN_CURRENCY_CODE',
		-- C.[Symbol]														'COLUMN_CURRENCY_SYMBOL',
		D.[ApiId]														'COLUMN_API_ID',
		D.[SystemService]												'COLUMN_SYSTEM_SERVICE',
		CASE WHEN D.[SystemService] = 'TRANSCRIPTION' 
			THEN SUM(ISNULL(D.[Rate], 0)) ELSE NULL END					'COLUMN_TRANSCRIPTION_TOTAL_RATE',
		D.[RatePerSecond]												'COLUMN_TRANSCRIPTION_RATE_PER_SECOND',
		SUM(ISNULL(D.[ValidDurationTime], 0))							'COLUMN_TRANSCRIPTION_VALID_DURATION_TIME',
		S.[SemanticAnalysisRatePerTransaction]							'COLUMN_SEMANTIC_ANALYSIS_RATE_PER_TRANSACTION',
		CASE WHEN S.[TotalQueries] > 0 THEN 1 ELSE NULL END				'COLUMN_SEMANTIC_ANALYSIS_TOTAL_REQUEST',
		CASE WHEN D.[SystemService] = 'SEMANTIC_ANALYSIS' 
			THEN SUM(ISNULL(D.[Rate], 0)) ELSE NULL END					'COLUMN_SEMANTIC_ANALYSIS_TOTAL_RATE',
		S.[CognitiveAnalysisRatePerTransaction]							'COLUMN_COGNITIVE_ANALYSIS_RATE_PER_TRANSACTION',
		CASE WHEN D.[SystemService] = 'COGNITIVE_ANALYSIS' 
			THEN SUM(D.[TotalValidRequest]) ELSE NULL END				'COLUMN_COGNITIVE_ANALYSIS_TOTAL_REQUEST',
		CASE WHEN D.[SystemService] = 'COGNITIVE_ANALYSIS' 
			THEN SUM(ISNULL(D.[Rate], 0)) ELSE NULL END					'COLUMN_COGNITIVE_ANALYSIS_TOTAL_RATE',
		D.[EntityId]													'COLUMN_ENTITY_ID'
	FROM AccountSubAccountVCCDetailedTransaction D (NOLOCK)
	LEFT JOIN AccountSubAccountVCCSummaryTransaction S (NOLOCK)
		ON S.BatchID = D.BatchId
			AND S.[SystemService] = D.[SystemService]
	INNER JOIN [dbo].[Currency] C (NOLOCK)
		ON C.[Code] = S.[CurrencyCode]
	WHERE D.[InstallationId] IS NOT NULL
		AND   (@InstallationId IS NULL OR D.[InstallationId] = @InstallationId)
		AND   (@StartDate IS NULL OR S.[EndDate] >= @StartDate)
		AND   (@EndDate IS NULL OR S.[EndDate] <= @EndDate)
		AND   (@BatchTypeName IS NULL OR D.[BatchTypeName] = @BatchTypeName)
		AND   (@BatchTypeId IS NULL OR D.[BatchTypeId] = @BatchTypeId)
		AND   (@AccountId IS NULL OR D.[AccountId] = @AccountId)
		AND   (
				((@SubAccountId IS NULL OR @SubAccountId = 'NONE') AND D.[SubAccountId] IS NULL)
				OR (@SubAccountId = 'ALL_SUBACCOUNTS' AND D.[SubAccountId] IS NOT NULL)
				OR D.[SubAccountId] = @SubAccountId
		)
		AND   (
				(@VCC IS NOT NULL AND D.[VCC] = @VCC)
				OR D.[VCC] IS NOT NULL
			)
		AND   (@UserApi IS NULL OR S.[UserApi] = @UserApi)
	GROUP BY D.[ClientId], 
				S.[StartDate], 
				S.[EndDate], 
				D.[BatchTypeName], 
				D.[BatchTypeId], 
				D.[AccountId], 
				D.[SubAccountId], 
				C.[Code], 
				-- C.[Symbol], 
				D.[ApiId], 
				D.[SystemService], 
				D.[RatePerSecond], 
				S.[SemanticAnalysisRatePerTransaction], 
				S.[TotalQueries], 
				S.[CognitiveAnalysisRatePerTransaction], 
				S.[TotalModelRequest], 
				D.[EntityId]

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
